local FOLDER_NAME, private = ...
local _G = _G
local LS = _G.LibStub
local core = LS("AceAddon-3.0"):GetAddon(FOLDER_NAME)
local L = LS("AceLocale-3.0"):GetLocale(FOLDER_NAME)
local clothbuild = GetAddOnMetadata(FOLDER_NAME, "X-Cloth-BuildDate")
local StaticPopup_Show = StaticPopup_Show
local pairs, type = pairs, type
local MODNAME = "Cloth"
local Cloth = core:NewModule(MODNAME, "AceEvent-3.0")
local db, getOpt, setOpt, options

local defaults = {
	profile = {
		van = false,
		bc = false,
		lk = false,
		cata = false,
		mop = false,
		wod = false,
		van = true,
		tracking = {
			['*'] = false
		},
	},
}

do
	function getOpt(info)
		local key = info[#info]
		return db[key]
	end
	function setOpt(info, value)
		local key = info[#info]
		db[key] = value
	end
end

local function getOptions()
	if not options then
		options = {
			type = "group",
			name = MODNAME,
			arg = MODNAME,
			get = getOpt,
			set = setOpt,
			args = {
				intro = {
					order = 0,
					type = "header",
					name = L["Cloth"].." "..L["Module"],
				},
				space = {
					order = 5,
					type = "description",
					name = " "
				},
				author = {
					order = 10,
					type = "description",
					name = L["Author: "]..private.author
				},
				version = {
					order = 15,
					type = "description",
					name = L["Version: "]..private.version
				},
				builddate = {
					order = 20,
					type = "description",
					name = L["Build Date: "]..clothbuild
				},
				space1 = {
					order = 25,
					type = "description",
					name = " "
				},
				enabled = {
					type = "toggle",
					order = 30,
					width = "full",
					name = L["Enable"].." / "..L["Disable"].." "..L["Cloth"].." "..L["Module"],
					desc = "|cffff0000"..L["Disabling a module requires a UI reload to remove it from the Broker display."].."|r",
					descStyle = "inline",
					get = function() return core:getModuleEnabled(MODNAME) end,
					set = function(info, value) core:setModuleEnabled(MODNAME, value) end,
				},
				space2 = {
					order = 35,
					type = "header",
					name = L["Module Expansion Filters"]
				},
				van = {
					type = "toggle",
					order = 40,
					width = "full",
					name = L["Enable"].." ".."|cffffff99"..L["Vanilla"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
				bc = {
					type = "toggle",
					order = 45,
					width = "full",
					name = L["Enable"].." ".."|cff00ff00"..L["The Burning Crusade"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
				lk = {
					type = "toggle",
					order = 50,
					width = "full",
					name = L["Enable"].." ".."|cff0066ff"..L["Wrath of the Lich King"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
				cata = {
					type = "toggle",
					order = 55,
					width = "full",
					name = L["Enable"].." ".."|cffff6600"..L["Cataclysm"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
				mop = {
					type = "toggle",
					order = 60,
					width = "full",
					name = L["Enable"].." ".."|cff19ac87"..L["Mists of Pandaria"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
				wod = {
					type = "toggle",
					order = 65,
					width = "full",
					name = L["Enable"].." ".."|cfffd482f"..L["Warlords of Draenor"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
				leg = {
					type = "toggle",
					order = 70,
					width = "full",
					name = L["Enable"].." ".."|cff299f06"..L["Legion"].."|r".." "..L["item counts in the tooltip."],
					hidden = function() return not core:getModuleEnabled(MODNAME) end
				},
			},
		}
	end
	return options
end

function Cloth:OnInitialize()
	self.db = core.db:RegisterNamespace(MODNAME, defaults)
	db = self.db.profile
	self:SetEnabledState(core:getModuleEnabled(MODNAME))
	core:registerModuleOptions(MODNAME, getOptions, MODNAME)
end

function Cloth:OnEnable()
	core:createDropdownMenu(MODNAME, "BPM"..MODNAME.."DD")
	core:createBroker(MODNAME)
	self:count()
	self:refresh()
end

function Cloth:OnDisable()
	StaticPopup_Show("BPMReload")
end

function Cloth:refresh()
	core:textUpdate(MODNAME)
end

function Cloth:count()
	for _, itemid in pairs(private.data[MODNAME].van.id) do
		core:saveCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].bc.id) do
		core:saveCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].lk.id) do
		core:saveCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].cata.id) do
		core:saveCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].mop.id) do
		core:saveCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].wod.id) do
		core:saveCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].leg.id) do
		core:saveCounts(itemid)
	end
	core:textUpdate(MODNAME)
end

function Cloth:countGuild()
	for _, itemid in pairs(private.data[MODNAME].van.id) do
		core:saveGuildCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].bc.id) do
		core:saveGuildCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].lk.id) do
		core:saveGuildCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].cata.id) do
		core:saveGuildCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].mop.id) do
		core:saveGuildCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].wod.id) do
		core:saveGuildCounts(itemid)
	end
	for _, itemid in pairs(private.data[MODNAME].leg.id) do
		core:saveGuildCounts(itemid)
	end
	private.scanPending = false
end
